Coverage report

# Coverage report: 50%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 193 | 97 | 0 | 50%
ejpiaj/__init__ | 6 | 0 | 0 | 100%
ejpiaj/assertions | 19 | 4 | 0 | 79%
ejpiaj/core | 60 | 50 | 0 | 17%
ejpiaj/decorators | 11 | 0 | 0 | 100%
ejpiaj/parsers | 3 | 3 | 0 | 0%
ejpiaj/registry | 28 | 8 | 0 | 71%
ejpiaj/runner | 30 | 30 | 0 | 0%
ejpiaj/variable_extractor | 36 | 2 | 0 | 94%